@@ -5,8 +5,11 @@
 
 .onAttach <- function(libname, pkgname)
 {
-  if(!requireNamespace("rolog", quietly=TRUE))
-    stop("Could not attach library rolog.")
+  if(!requireNamespace("rolog", quiet=TRUE))
+    stop("Could not load R package rolog.")
+
+  if(!rolog::rolog_ok())
+    stop("Could not attach R package rolog.")
 
   rolog::consult(system.file("pl/mathml.pl", package=pkgname))
 }
